import { computed, defineComponent, openBlock, createElementBlock, unref, resolveComponent, createBlock, resolveDynamicComponent, mergeProps, withCtx, createTextVNode, toDisplayString, createVNode, normalizeClass, Fragment, renderList, createElementVNode, createCommentVNode, normalizeProps, guardReactiveProps, useSlots, toRefs, normalizeStyle, renderSlot, ref, onMounted } from 'vue';
import katex from 'katex';
import Prism from 'prismjs';
import { Fragment as Fragment$1 } from 'fragment-for-vue/vue3';
import 'prismjs/themes/prism.css';
import 'katex/dist/katex.min.css';

// utils from react-notion
const getTextContent = (text) => {
    return text.reduce((prev, current) => prev + current[0], "");
};
const groupBlockContent = (blockMap) => {
    const output = [];
    let lastType = undefined;
    let index = -1;
    Object.keys(blockMap).forEach((id) => {
        blockMap[id].value.content?.forEach((blockId) => {
            const blockType = blockMap[blockId]?.value?.type;
            if (blockType && blockType !== lastType) {
                index++;
                lastType = blockType;
                output[index] = [];
            }
            output[index].push(blockId);
        });
        lastType = undefined;
    });
    return output;
};
const getListNumber = (blockId, blockMap) => {
    const groups = groupBlockContent(blockMap);
    const group = groups.find((g) => g.includes(blockId));
    if (!group) {
        return;
    }
    return group.indexOf(blockId) + 1;
};
const defaultMapImageUrl = (image = "", block) => {
    const url = new URL(`https://www.notion.so${image.startsWith("/image") ? image : `/image/${encodeURIComponent(image)}`}`);
    if (block && !image.includes("/images/page-cover/")) {
        const table = block.value.parent_table === "space" ? "block" : block.value.parent_table;
        url.searchParams.set("table", table);
        url.searchParams.set("id", block.value.id);
        url.searchParams.set("cache", "v2");
    }
    return url.toString();
};
const defaultMapPageUrl = (pageId = "") => {
    pageId = pageId.replace(/-/g, "");
    return `/${pageId}`;
};

const defineNotionProps = {
    blockMap: { type: Object, required: true },
    contentId: { type: String, required: false },
    contentIndex: { type: Number, default: 0 },
    embedAllow: { type: String, default: "fullscreen" },
    fullPage: { type: Boolean, default: false },
    hideList: { type: Array, default: () => [] },
    level: { type: Number, default: 0 },
    mapImageUrl: { type: Function, default: defaultMapImageUrl },
    mapPageUrl: { type: Function, default: defaultMapPageUrl },
    pageLinkOptions: Object,
    pageLinkTarget: { type: String, default: "_self" },
    prism: { type: Boolean, default: false },
    katex: { type: Boolean, default: false },
    textLinkTarget: { type: String, default: "_blank" },
};
const useNotionBlock = (props) => {
    const block = computed(() => {
        const id = props.contentId || Object.keys(props.blockMap)[0];
        return props.blockMap[id];
    });
    const pass = computed(() => {
        return {
            blockMap: props.blockMap,
            contentId: props.contentId,
            contentIndex: props.contentIndex,
            embedAllow: props.embedAllow,
            fullPage: props.fullPage,
            hideList: props.hideList,
            level: props.level,
            mapImageUrl: props.mapImageUrl,
            mapPageUrl: props.mapPageUrl,
            pageLinkOptions: props.pageLinkOptions,
            prism: props.prism,
            katex: props.katex,
        };
    });
    const f = computed(() => {
        return {
            block_aspect_ratio: block.value?.value?.format?.block_aspect_ratio,
            block_height: block.value?.value?.format?.block_height || 1,
            block_width: block.value?.value?.format?.block_width || 1,
            block_color: block.value?.value?.format?.block_color,
            bookmark_icon: block.value?.value?.format?.bookmark_icon,
            bookmark_cover: block.value?.value?.format?.bookmark_cover,
            display_source: block.value?.value?.format?.display_source,
        };
    });
    const format = computed(() => block.value?.value.format);
    const properties = computed(() => block.value?.value.properties);
    const icon = computed(() => format.value?.page_icon);
    const width = computed(() => format.value?.block_width);
    const title = computed(() => properties.value?.title);
    const caption = computed(() => properties.value?.caption);
    const description = computed(() => properties.value?.description);
    const type = computed(() => {
        return block.value?.value.type;
    });
    const visible = computed(() => {
        return type.value ? !props.hideList?.includes(type.value) : false;
    });
    const hasPageLinkOptions = computed(() => {
        return props.pageLinkOptions?.component && props.pageLinkOptions?.href;
    });
    const parent = computed(() => {
        return props.blockMap[block.value?.value.parent_id];
    });
    const isType = (t) => {
        if (Array.isArray(t)) {
            return visible.value && t.includes(type.value);
        }
        return visible.value && type.value === t;
    };
    const blockColorClass = (suffix = "") => {
        const blockColor = block.value?.value?.format?.block_color;
        return blockColor ? `notion-${blockColor}${suffix}` : undefined;
    };
    const pageLinkProps = (id) => {
        return props.pageLinkOptions
            ? {
                [props.pageLinkOptions.href]: props.mapPageUrl(id),
            }
            : {};
    };
    return {
        props,
        block,
        pass,
        f,
        format,
        properties,
        icon,
        width,
        title,
        caption,
        description,
        type,
        visible,
        hasPageLinkOptions,
        parent,
        isType,
        blockColorClass,
        pageLinkProps,
    };
};

const availableType = [
    "page",
    "header",
    "sub_header",
    "sub_sub_header",
    "bookmark",
    "callout",
    "code",
    "equation",
    "text",
    "quote",
    "to_do",
    "toggle",
    "column_list",
    "column",
    "bulleted_list",
    "numbered_list",
    "image",
    "embed",
    "figma",
    "video",
    "audio",
    "table",
    "table_row",
    "divider",
    "table_of_contents",
];

const _hoisted_1$m = ["innerHTML"];
const __default__$n = {
    name: "Katex",
};
var script$q = /*#__PURE__*/ defineComponent({
    ...__default__$n,
    props: {
        expression: {
            type: String,
            required: true,
        },
    },
    setup(__props) {
        const props = __props;
        const html = computed(() => katex.renderToString(props.expression));
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("span", { innerHTML: unref(html) }, null, 8 /* PROPS */, _hoisted_1$m));
        };
    }
});

script$q.__file = "src/blocks/helpers/katex.vue";

const _hoisted_1$l = ["target", "href"];
const _hoisted_2$f = ["target", "href"];
const _hoisted_3$5 = ["target", "href"];
const _hoisted_4$2 = { key: 5 };
const _hoisted_5$2 = {
    key: 7,
    class: "notion-inline-code"
};
const _hoisted_6$2 = { key: 8 };
const _hoisted_7$2 = { key: 9 };
const _hoisted_8$2 = { key: 10 };
const _hoisted_9 = {
    key: 11,
    class: "notion-underline"
};
const _hoisted_10 = {
    key: 13,
    class: "notion-inline-code"
};
const __default__$m = {
    name: "NotionDecorator",
};
var script$p = /*#__PURE__*/ defineComponent({
    ...__default__$m,
    props: {
        content: Object,
        ...defineNotionProps,
    },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { props: blockProps, pass, type, hasPageLinkOptions, pageLinkProps } = useNotionBlock(props);
        const text = computed(() => props.content?.[0]);
        const decorators = computed(() => props.content?.[1] || []);
        const decoratorKey = computed(() => decorators.value?.[0]?.[0]);
        const decoratorValue = computed(() => decorators.value?.[0]?.[1]);
        const unappliedDecorators = computed(() => {
            const clonedDecorators = JSON.parse(JSON.stringify(decorators.value || []));
            clonedDecorators.shift(); // remove applied decorator
            return clonedDecorators;
        });
        const nextContent = computed(() => [text.value, unappliedDecorators.value]);
        const isPageLink = computed(() => text.value === "‣");
        const isInlinePageLink = computed(() => decoratorValue.value?.[0] === "/");
        const pageLinkTitle = computed(() => blockProps.blockMap?.[decoratorValue.value]?.value?.properties?.title?.[0]?.[0] || "link");
        const target = computed(() => {
            if (type.value === "page") {
                return blockProps.pageLinkTarget;
            }
            return blockProps.textLinkTarget;
        });
        return (_ctx, _cache) => {
            const _component_NotionDecorator = resolveComponent("NotionDecorator");
            return (unref(isPageLink) && unref(hasPageLinkOptions))
                ? (openBlock(), createBlock(resolveDynamicComponent(unref(blockProps).pageLinkOptions?.component), mergeProps({
                    key: 0,
                    class: "notion-link"
                }, unref(pageLinkProps)(unref(decoratorValue))), {
                    default: withCtx(() => [
                        createTextVNode(toDisplayString(unref(pageLinkTitle)), 1 /* TEXT */)
                    ]),
                    _: 1 /* STABLE */
                }, 16 /* FULL_PROPS */))
                : (unref(isPageLink))
                    ? (openBlock(), createElementBlock("a", {
                        key: 1,
                        class: "notion-link",
                        target: unref(blockProps).pageLinkTarget,
                        href: unref(blockProps).mapPageUrl(unref(decoratorValue))
                    }, toDisplayString(unref(pageLinkTitle)), 9 /* TEXT, PROPS */, _hoisted_1$l))
                    : (unref(decoratorKey) === 'a' && unref(hasPageLinkOptions) && unref(isInlinePageLink))
                        ? (openBlock(), createBlock(resolveDynamicComponent(unref(blockProps).pageLinkOptions?.component), mergeProps({
                            key: 2,
                            class: "notion-link"
                        }, unref(pageLinkProps)(unref(decoratorValue).slice(1))), {
                            default: withCtx(() => [
                                createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                            ]),
                            _: 1 /* STABLE */
                        }, 16 /* FULL_PROPS */))
                        : (unref(decoratorKey) === 'a' && unref(isInlinePageLink))
                            ? (openBlock(), createElementBlock("a", {
                                key: 3,
                                class: "notion-link",
                                target: unref(target),
                                href: unref(blockProps).mapPageUrl(unref(decoratorValue).slice(1))
                            }, [
                                createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                            ], 8 /* PROPS */, _hoisted_2$f))
                            : (unref(decoratorKey) === 'a')
                                ? (openBlock(), createElementBlock("a", {
                                    key: 4,
                                    class: "notion-link",
                                    target: unref(target),
                                    href: unref(decoratorValue)
                                }, [
                                    createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                ], 8 /* PROPS */, _hoisted_3$5))
                                : (unref(decorators).length === 0)
                                    ? (openBlock(), createElementBlock("span", _hoisted_4$2, toDisplayString(unref(text)), 1 /* TEXT */))
                                    : (unref(decoratorKey) === 'h')
                                        ? (openBlock(), createElementBlock("span", {
                                            key: 6,
                                            class: normalizeClass('notion-' + unref(decoratorValue))
                                        }, [
                                            createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                        ], 2 /* CLASS */))
                                        : (unref(decoratorKey) === 'c')
                                            ? (openBlock(), createElementBlock("code", _hoisted_5$2, [
                                                createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                            ]))
                                            : (unref(decoratorKey) === 'b')
                                                ? (openBlock(), createElementBlock("b", _hoisted_6$2, [
                                                    createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                                ]))
                                                : (unref(decoratorKey) === 'i')
                                                    ? (openBlock(), createElementBlock("em", _hoisted_7$2, [
                                                        createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                                    ]))
                                                    : (unref(decoratorKey) === 's')
                                                        ? (openBlock(), createElementBlock("s", _hoisted_8$2, [
                                                            createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                                        ]))
                                                        : (unref(decoratorKey) === '_')
                                                            ? (openBlock(), createElementBlock("u", _hoisted_9, [
                                                                createVNode(_component_NotionDecorator, mergeProps({ content: unref(nextContent) }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"])
                                                            ]))
                                                            : (unref(decoratorKey) === 'e' && unref(blockProps).katex)
                                                                ? (openBlock(), createBlock(script$q, {
                                                                    key: 12,
                                                                    expression: unref(decoratorValue)
                                                                }, null, 8 /* PROPS */, ["expression"]))
                                                                : (unref(decoratorKey) === 'e')
                                                                    ? (openBlock(), createElementBlock("code", _hoisted_10, toDisplayString(unref(decoratorValue)), 1 /* TEXT */))
                                                                    : (openBlock(), createBlock(_component_NotionDecorator, mergeProps({
                                                                        key: 14,
                                                                        content: unref(nextContent)
                                                                    }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"]));
        };
    }
});

script$p.__file = "src/blocks/decorator.vue";

const __default__$l = {
    name: "NotionTextRenderer",
};
var script$o = /*#__PURE__*/ defineComponent({
    ...__default__$l,
    props: { text: Object, ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { pass, format } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("span", null, [
                (openBlock(true), createElementBlock(Fragment, null, renderList(__props.text, (t, i) => {
                    return (openBlock(), createBlock(script$p, mergeProps({
                        key: i,
                        content: t
                    }, unref(pass)), null, 16 /* FULL_PROPS */, ["content"]));
                }), 128 /* KEYED_FRAGMENT */))
            ]));
        };
    }
});

script$o.__file = "src/blocks/helpers/text-renderer.vue";

const _hoisted_1$k = { class: "notion-row" };
const _hoisted_2$e = ["href"];
const _hoisted_3$4 = { class: "notion-bookmark-title" };
const _hoisted_4$1 = {
    key: 0,
    class: "notion-bookmark-description"
};
const _hoisted_5$1 = { class: "notion-bookmark-link" };
const _hoisted_6$1 = ["alt", "src"];
const _hoisted_7$1 = {
    key: 0,
    class: "notion-bookmark-image"
};
const _hoisted_8$1 = ["alt", "src"];
const __default__$k = {
    name: "NotionBookmark",
};
var script$n = /*#__PURE__*/ defineComponent({
    ...__default__$k,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { f, properties, title, description, pass } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", _hoisted_1$k, [
                createElementVNode("a", {
                    target: "_blank",
                    rel: "noopener noreferrer",
                    class: normalizeClass(['notion-bookmark', unref(f).block_color && `notion-${unref(f).block_color}`]),
                    href: unref(properties).link[0][0]
                }, [
                    createElementVNode("div", null, [
                        createElementVNode("div", _hoisted_3$4, [
                            createVNode(script$o, mergeProps({
                                text: unref(title) || unref(properties).link
                            }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ]),
                        (unref(description))
                            ? (openBlock(), createElementBlock("div", _hoisted_4$1, [
                                createVNode(script$o, mergeProps({ text: unref(description) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                            ]))
                            : createCommentVNode("v-if", true),
                        createElementVNode("div", _hoisted_5$1, [
                            (unref(f).bookmark_icon)
                                ? (openBlock(), createElementBlock("img", {
                                    key: 0,
                                    alt: unref(getTextContent)(unref(title) || unref(properties).link),
                                    src: unref(f).bookmark_icon
                                }, null, 8 /* PROPS */, _hoisted_6$1))
                                : createCommentVNode("v-if", true),
                            createElementVNode("div", null, [
                                createVNode(script$o, mergeProps({
                                    text: unref(properties).link
                                }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                            ])
                        ])
                    ]),
                    (unref(f).bookmark_cover)
                        ? (openBlock(), createElementBlock("div", _hoisted_7$1, [
                            createElementVNode("img", {
                                alt: unref(getTextContent)(unref(title) || unref(properties).link),
                                src: unref(f).bookmark_cover
                            }, null, 8 /* PROPS */, _hoisted_8$1)
                        ]))
                        : createCommentVNode("v-if", true)
                ], 10 /* CLASS, PROPS */, _hoisted_2$e)
            ]));
        };
    }
});

script$n.__file = "src/blocks/bookmark.vue";

const _hoisted_1$j = ["src", "alt"];
const _hoisted_2$d = ["aria-label"];
const __default__$j = {
    name: "NotionPageIcon",
};
var script$m = /*#__PURE__*/ defineComponent({
    ...__default__$j,
    props: { big: Boolean, ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { icon, format, block, title } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (unref(icon)?.includes('http'))
                ? (openBlock(), createElementBlock("img", {
                    key: 0,
                    class: normalizeClass([unref(format).page_cover && 'notion-page-icon-offset', __props.big ? 'notion-page-icon-cover' : 'notion-page-icon']),
                    src: props.mapImageUrl(unref(icon), unref(block)),
                    alt: unref(title) ? unref(getTextContent)(unref(title)) : 'Icon'
                }, null, 10 /* CLASS, PROPS */, _hoisted_1$j))
                : (unref(icon))
                    ? (openBlock(), createElementBlock("span", {
                        key: 1,
                        role: "img",
                        "aria-label": unref(icon),
                        class: normalizeClass([
                            'notion-emoji',
                            unref(format).page_cover && 'notion-page-icon-offset',
                            __props.big ? 'notion-page-icon-cover' : 'notion-page-icon',
                        ])
                    }, toDisplayString(unref(icon)), 11 /* TEXT, CLASS, PROPS */, _hoisted_2$d))
                    : createCommentVNode("v-if", true);
        };
    }
});

script$m.__file = "src/blocks/helpers/page-icon.vue";

const _hoisted_1$i = { style: { "font-size": "12px" } };
const _hoisted_2$c = { class: "notion-callout-text" };
const __default__$i = {
    name: "NotionCallout",
};
var script$l = /*#__PURE__*/ defineComponent({
    ...__default__$i,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { pass, title, blockColorClass } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", {
                class: normalizeClass(['notion-callout', unref(blockColorClass)()])
            }, [
                createElementVNode("div", _hoisted_1$i, [
                    createVNode(script$m, normalizeProps(guardReactiveProps(unref(pass))), null, 16 /* FULL_PROPS */)
                ]),
                createElementVNode("div", _hoisted_2$c, [
                    createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ])
            ], 2 /* CLASS */));
        };
    }
});

script$l.__file = "src/blocks/callout.vue";

const _hoisted_1$h = ["innerHTML"];
const _hoisted_2$b = ["innerHTML"];
var script$k = /*#__PURE__*/ defineComponent({
    props: {
        code: {
            type: String,
        },
        inline: {
            type: Boolean,
            default: false,
        },
        language: {
            type: String,
            default: "markup",
        },
    },
    setup(__props) {
        const props = __props;
        const slots = useSlots();
        const { inline, language } = toRefs(props);
        const className = computed(() => `language-${language.value}`);
        const defaultSlot = (slots && slots.default && slots.default()) || [];
        const code = props.code || (defaultSlot && defaultSlot.length && defaultSlot[0]?.children)
            ? defaultSlot[0].children
            : "";
        const d = computed(() => Prism?.highlight(code, Prism?.languages[language.value], "en"));
        return (_ctx, _cache) => {
            return (unref(inline))
                ? (openBlock(), createElementBlock("code", {
                    key: 0,
                    class: normalizeClass(unref(className)),
                    innerHTML: unref(d)
                }, null, 10 /* CLASS, PROPS */, _hoisted_1$h))
                : (openBlock(), createElementBlock("pre", {
                    key: 1,
                    class: normalizeClass(unref(className))
                }, [
                    createElementVNode("code", { innerHTML: unref(d) }, null, 8 /* PROPS */, _hoisted_2$b)
                ], 2 /* CLASS */));
        };
    }
});

script$k.__file = "src/blocks/helpers/prism.vue";

const _hoisted_1$g = {
    key: 0,
    class: /*#__PURE__*/ normalizeClass(['notion-code'])
};
const _hoisted_2$a = {
    key: 1,
    class: /*#__PURE__*/ normalizeClass(['notion-code'])
};
const __default__$h = {
    name: "NotionCode",
};
var script$j = /*#__PURE__*/ defineComponent({
    ...__default__$h,
    props: { overrideLang: String, overrideLangClass: String, ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { properties } = useNotionBlock(props);
        const lang = computed(() => {
            return props.overrideLang || properties.value?.language?.[0]?.[0]?.toLowerCase();
        });
        const langClass = computed(() => {
            return props.overrideLangClass || `language-${lang.value}`;
        });
        const supported = computed(() => {
            return lang.value ? Prism?.languages[lang.value] : false;
        });
        return (_ctx, _cache) => {
            return (unref(supported))
                ? (openBlock(), createElementBlock("div", _hoisted_1$g, [
                    createVNode(script$k, { language: unref(lang) }, {
                        default: withCtx(() => [
                            createTextVNode(toDisplayString(unref(properties)?.title[0][0]), 1 /* TEXT */)
                        ]),
                        _: 1 /* STABLE */
                    }, 8 /* PROPS */, ["language"])
                ]))
                : (openBlock(), createElementBlock("div", _hoisted_2$a, [
                    createElementVNode("pre", null, [
                        createElementVNode("code", {
                            class: normalizeClass(unref(langClass))
                        }, toDisplayString(unref(properties)?.title[0][0]), 3 /* TEXT, CLASS */)
                    ])
                ]));
        };
    }
});

script$j.__file = "src/blocks/code.vue";

const __default__$g = {
    name: "NotionColumn",
};
var script$i = /*#__PURE__*/ defineComponent({
    ...__default__$g,
    props: {
        format: { type: Object, required: true },
    },
    setup(__props) {
        const props = __props;
        const baseWidth = 46; // todo: add magic numbers to a config json
        const columnStyle = computed(() => {
            const columns = Number((1 / props.format.column_ratio).toFixed(0));
            const totalWidth = (columns - 1) * baseWidth;
            return {
                width: `calc((100% - ${totalWidth}px) * ${props.format.column_ratio})`,
            };
        });
        const spacerStyle = computed(() => ({ width: `${baseWidth}px` }));
        return (_ctx, _cache) => {
            return (openBlock(), createBlock(unref(Fragment$1), null, {
                default: withCtx(() => [
                    createElementVNode("div", {
                        class: "notion-column",
                        style: normalizeStyle(unref(columnStyle))
                    }, [
                        renderSlot(_ctx.$slots, "default")
                    ], 4 /* STYLE */),
                    createElementVNode("div", {
                        class: "notion-spacer",
                        style: normalizeStyle(unref(spacerStyle))
                    }, null, 4 /* STYLE */)
                ]),
                _: 3 /* FORWARDED */
            }));
        };
    }
});

script$i.__file = "src/blocks/column.vue";

const _hoisted_1$f = { key: 0 };
const __default__$f = {
    name: "NotionEquation",
};
var script$h = /*#__PURE__*/ defineComponent({
    ...__default__$f,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { properties, pass } = useNotionBlock(props);
        const equation = computed(() => properties.value.title?.[0]?.[0]);
        return (_ctx, _cache) => {
            return (props.katex)
                ? (openBlock(), createElementBlock("div", _hoisted_1$f, [
                    createVNode(script$q, { expression: unref(equation) }, null, 8 /* PROPS */, ["expression"])
                ]))
                : (openBlock(), createBlock(script$j, mergeProps({ key: 1 }, unref(pass), {
                    overrideLang: "latex",
                    overrideLangClass: "language-latex"
                }), null, 16 /* FULL_PROPS */));
        };
    }
});

script$h.__file = "src/blocks/equation.vue";

const _hoisted_1$e = ["src", "allow"];
const __default__$e = {
    name: "NotionAsset",
};
var script$g = /*#__PURE__*/ defineComponent({
    ...__default__$e,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { type, properties, f } = useNotionBlock(props);
        const src = computed(() => {
            return type.value === "figma" ? properties.value?.source[0][0] : f.value.display_source;
        });
        const style = computed(() => {
            const aspectRatio = f.value.block_aspect_ratio || f.value.block_height / f.value.block_width;
            return {
                paddingBottom: `${aspectRatio * 100}%`,
                position: "relative",
            };
        });
        return (_ctx, _cache) => {
            return (unref(src))
                ? (openBlock(), createElementBlock("div", {
                    key: 0,
                    style: normalizeStyle(unref(style))
                }, [
                    createElementVNode("iframe", {
                        class: "notion-image-inset",
                        style: { "width": "100%" },
                        src: unref(src),
                        allow: props.embedAllow
                    }, null, 8 /* PROPS */, _hoisted_1$e)
                ], 4 /* STYLE */))
                : createCommentVNode("v-if", true);
        };
    }
});

script$g.__file = "src/blocks/helpers/asset.vue";

const _hoisted_1$d = ["alt", "src"];
const _hoisted_2$9 = ["alt", "src"];
const __default__$d = {
    name: "NotionImage",
};
var script$f = /*#__PURE__*/ defineComponent({
    ...__default__$d,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { caption, properties, block, f } = useNotionBlock(props);
        const alt = computed(() => {
            return caption?.value?.[0][0];
        });
        const src = computed(() => {
            return props.mapImageUrl(properties.value?.source[0][0], block.value);
        });
        const aspectRatioStyle = computed(() => {
            let aspectRatio = f.value.block_width == 1 || f.value.block_height == 1
                ? 1 / f.value.block_aspect_ratio
                : `${f.value.block_width} / ${f.value.block_height} `;
            return {
                width: `${f.value.block_width}px`,
                height: `100%`,
                maxWidth: "100%",
                position: "relative",
                aspectRatio,
            };
        });
        const basicStyle = computed(() => {
            return {
                width: f.value.block_width == 1 ? "100%" : `${f.value.block_width}px`,
                height: f.value.block_height == 1 ? "100%" : `${f.value.block_height}px`,
            };
        });
        return (_ctx, _cache) => {
            return (unref(f).block_aspect_ratio)
                ? (openBlock(), createElementBlock("div", {
                    key: 0,
                    style: normalizeStyle(unref(aspectRatioStyle))
                }, [
                    createElementVNode("img", {
                        class: "notion-image-inset",
                        alt: unref(alt) || 'Notion image',
                        src: unref(src)
                    }, null, 8 /* PROPS */, _hoisted_1$d)
                ], 4 /* STYLE */))
                : (openBlock(), createElementBlock("img", {
                    key: 1,
                    alt: unref(alt),
                    src: unref(src),
                    style: normalizeStyle(unref(basicStyle))
                }, null, 12 /* STYLE, PROPS */, _hoisted_2$9));
        };
    }
});

script$f.__file = "src/blocks/helpers/image.vue";

const _hoisted_1$c = {
    key: 2,
    class: "notion-image-caption"
};
const __default__$c = {
    name: "NotionFigure",
};
var script$e = /*#__PURE__*/ defineComponent({
    ...__default__$c,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { pass, width, caption, isType } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("figure", {
                class: "notion-asset-wrapper",
                style: normalizeStyle(unref(width))
            }, [
                (unref(isType)('image'))
                    ? (openBlock(), createBlock(script$f, normalizeProps(mergeProps({ key: 0 }, unref(pass))), null, 16 /* FULL_PROPS */))
                    : (unref(isType)(['embed', 'video', 'figma']))
                        ? (openBlock(), createBlock(script$g, normalizeProps(mergeProps({ key: 1 }, unref(pass))), null, 16 /* FULL_PROPS */))
                        : createCommentVNode("v-if", true),
                (unref(caption))
                    ? (openBlock(), createElementBlock("figcaption", _hoisted_1$c, [
                        createVNode(script$o, mergeProps({ text: unref(caption) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                    ]))
                    : createCommentVNode("v-if", true)
            ], 4 /* STYLE */));
        };
    }
});

script$e.__file = "src/blocks/helpers/figure.vue";

const _hoisted_1$b = ["id"];
const _hoisted_2$8 = ["id"];
const _hoisted_3$3 = ["id"];
const __default__$b = {
    name: "NotionHeader",
};
var script$d = /*#__PURE__*/ defineComponent({
    ...__default__$b,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { type, title, pass, block } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (unref(type) === 'header')
                ? (openBlock(), createElementBlock("h1", {
                    key: 0,
                    class: "notion-h1",
                    id: unref(block).value.id
                }, [
                    createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ], 8 /* PROPS */, _hoisted_1$b))
                : (unref(type) === 'sub_header')
                    ? (openBlock(), createElementBlock("h2", {
                        key: 1,
                        class: "notion-h2",
                        id: unref(block).value.id
                    }, [
                        createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                    ], 8 /* PROPS */, _hoisted_2$8))
                    : (unref(type) === 'sub_sub_header')
                        ? (openBlock(), createElementBlock("h3", {
                            key: 2,
                            class: "notion-h3",
                            id: unref(block).value.id
                        }, [
                            createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ], 8 /* PROPS */, _hoisted_3$3))
                        : createCommentVNode("v-if", true);
        };
    }
});

script$d.__file = "src/blocks/header.vue";

const _hoisted_1$a = {
    key: 0,
    class: "notion-list notion-list-disc"
};
const _hoisted_2$7 = {
    key: 1,
    class: "notion-list notion-list-numbered"
};
const __default__$a = {
    name: "NotionNestedList",
};
var script$c = /*#__PURE__*/ defineComponent({
    ...__default__$a,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { block, type } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (unref(type) === 'bulleted_list')
                ? (openBlock(), createElementBlock("ul", _hoisted_1$a, [
                    renderSlot(_ctx.$slots, "default")
                ]))
                : (openBlock(), createElementBlock("ol", _hoisted_2$7, [
                    renderSlot(_ctx.$slots, "default")
                ]));
        };
    }
});

script$c.__file = "src/blocks/helpers/nested-list.vue";

const _hoisted_1$9 = {
    key: 0,
    class: "notion-list notion-list-disc"
};
const _hoisted_2$6 = ["start"];
const _hoisted_3$2 = { key: 2 };
const __default__$9 = {
    name: "NotionList",
};
var script$b = /*#__PURE__*/ defineComponent({
    ...__default__$9,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { block, type, title, pass } = useNotionBlock(props);
        const start = computed(() => {
            return props.blockMap
                ? block.value?.value?.format?.list_start_index || getListNumber(block.value.value.id, props.blockMap)
                : 0;
        });
        const isTopLevel = computed(() => type.value != props.blockMap?.[block.value.value.parent_id].value.type);
        return (_ctx, _cache) => {
            return (unref(isTopLevel) && unref(type) === 'bulleted_list')
                ? (openBlock(), createElementBlock("ul", _hoisted_1$9, [
                    createElementVNode("li", null, [
                        createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                    ]),
                    (unref(block).value.content)
                        ? (openBlock(), createBlock(script$c, normalizeProps(mergeProps({ key: 0 }, unref(pass))), {
                            default: withCtx(() => [
                                renderSlot(_ctx.$slots, "default")
                            ]),
                            _: 3 /* FORWARDED */
                        }, 16 /* FULL_PROPS */))
                        : createCommentVNode("v-if", true)
                ]))
                : (unref(isTopLevel) && unref(type) === 'numbered_list')
                    ? (openBlock(), createElementBlock("ol", {
                        key: 1,
                        class: "notion-list notion-list-numbered",
                        start: unref(start)
                    }, [
                        createElementVNode("li", null, [
                            createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ]),
                        (unref(block).value.content)
                            ? (openBlock(), createBlock(script$c, mergeProps({
                                key: 0,
                                class: [_ctx.level == 1 ? 'notion-list-flat' : '']
                            }, unref(pass)), {
                                default: withCtx(() => [
                                    renderSlot(_ctx.$slots, "default")
                                ]),
                                _: 3 /* FORWARDED */
                            }, 16 /* FULL_PROPS */, ["class"]))
                            : createCommentVNode("v-if", true)
                    ], 8 /* PROPS */, _hoisted_2$6))
                    : (openBlock(), createElementBlock("span", _hoisted_3$2, [
                        createElementVNode("li", {
                            class: normalizeClass([_ctx.level != 1 ? 'notion-list-indent' : ''])
                        }, [
                            createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ], 2 /* CLASS */),
                        (unref(block).value.content)
                            ? (openBlock(), createBlock(script$c, normalizeProps(mergeProps({ key: 0 }, unref(pass))), {
                                default: withCtx(() => [
                                    renderSlot(_ctx.$slots, "default")
                                ]),
                                _: 3 /* FORWARDED */
                            }, 16 /* FULL_PROPS */))
                            : createCommentVNode("v-if", true)
                    ]));
        };
    }
});

script$b.__file = "src/blocks/list.vue";

const _hoisted_1$8 = ["alt", "src"];
const _hoisted_2$5 = { class: "notion-title" };
const _hoisted_3$1 = {
    key: 1,
    class: "notion"
};
const _hoisted_4 = { class: "notion-page-icon" };
const _hoisted_5 = { class: "notion-page-text" };
const _hoisted_6 = ["target", "href"];
const _hoisted_7 = { class: "notion-page-icon" };
const _hoisted_8 = { class: "notion-page-text" };
const __default__$8 = {
    name: "NotionPage",
};
var script$a = /*#__PURE__*/ defineComponent({
    ...__default__$8,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { format, title, block, pass, hasPageLinkOptions, pageLinkProps } = useNotionBlock(props);
        const coverStyle = computed(() => {
            const coverPosition = (1 - (format.value.page_cover_position || 0.5)) * 100;
            return { objectPosition: `center ${coverPosition}%` };
        });
        const computedFont = computed(() => {
            let font = block.value.value.format?.page_font || "";
            if (font == "serif") {
                return { fontFamily: "Lyon-Text, Georgia, ui-serif, serif" };
            }
            else if (font == "mono") {
                return { fontFamily: "iawriter-mono, Nitti, Menlo, Courier, monospace" };
            }
        });
        return (_ctx, _cache) => {
            return (props.level === 0 && props.fullPage)
                ? (openBlock(), createElementBlock("div", {
                    key: 0,
                    class: "notion",
                    style: normalizeStyle(unref(computedFont))
                }, [
                    createCommentVNode(" todo: add header "),
                    createCommentVNode(" <NotionPageHeader v-if=\"!hideHeader\" v-bind=\"pass\" /> "),
                    createCommentVNode(" todo: hide image if no .format is available "),
                    (unref(format) && unref(format).page_cover)
                        ? (openBlock(), createElementBlock("img", {
                            key: 0,
                            class: "notion-page-cover",
                            style: normalizeStyle(unref(coverStyle)),
                            alt: unref(getTextContent)(unref(title)),
                            src: props.mapImageUrl(unref(format).page_cover, unref(block))
                        }, null, 12 /* STYLE, PROPS */, _hoisted_1$8))
                        : createCommentVNode("v-if", true),
                    createElementVNode("main", {
                        class: normalizeClass([
                            'notion-page',
                            unref(format) && !unref(format).page_cover && 'notion-page-offset',
                            unref(format) && unref(format).page_full_width && 'notion-full-width',
                            unref(format) && unref(format).page_small_text && 'notion-small-text',
                        ])
                    }, [
                        createVNode(script$m, mergeProps(unref(pass), { big: "" }), null, 16 /* FULL_PROPS */),
                        createElementVNode("div", _hoisted_2$5, [
                            createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                        ]),
                        renderSlot(_ctx.$slots, "default")
                    ], 2 /* CLASS */)
                ], 4 /* STYLE */))
                : (props.level === 0)
                    ? (openBlock(), createElementBlock("main", _hoisted_3$1, [
                        renderSlot(_ctx.$slots, "default")
                    ]))
                    : (unref(hasPageLinkOptions))
                        ? (openBlock(), createBlock(resolveDynamicComponent(props.pageLinkOptions?.component), mergeProps({
                            key: 2,
                            class: "notion-page-link"
                        }, unref(pageLinkProps)(unref(block).value.id)), {
                            default: withCtx(() => [
                                createElementVNode("div", _hoisted_4, [
                                    createVNode(script$m, normalizeProps(guardReactiveProps(unref(pass))), null, 16 /* FULL_PROPS */)
                                ]),
                                createElementVNode("div", _hoisted_5, [
                                    createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                                ])
                            ]),
                            _: 1 /* STABLE */
                        }, 16 /* FULL_PROPS */))
                        : (openBlock(), createElementBlock("a", {
                            key: 3,
                            class: "notion-page-link",
                            target: props.pageLinkTarget,
                            href: props.mapPageUrl(unref(block).value.id)
                        }, [
                            createElementVNode("div", _hoisted_7, [
                                createVNode(script$m, normalizeProps(guardReactiveProps(unref(pass))), null, 16 /* FULL_PROPS */)
                            ]),
                            createElementVNode("div", _hoisted_8, [
                                createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                            ])
                        ], 8 /* PROPS */, _hoisted_6));
        };
    }
});

script$a.__file = "src/blocks/page.vue";

const _hoisted_1$7 = {
    key: 0,
    class: "notion-quote"
};
const __default__$7 = {
    name: "NotionQuote",
};
var script$9 = /*#__PURE__*/ defineComponent({
    ...__default__$7,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { properties, title, pass } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (unref(properties))
                ? (openBlock(), createElementBlock("blockquote", _hoisted_1$7, [
                    createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ]))
                : createCommentVNode("v-if", true);
        };
    }
});

script$9.__file = "src/blocks/quote.vue";

var script$8 = {
    name: "NotionTable",
};

const _hoisted_1$6 = { class: "notion-simple-table-wrapper" };
const _hoisted_2$4 = { class: "notion-simple-table" };

function render(_ctx, _cache, $props, $setup, $data, $options) {
  return (openBlock(), createElementBlock("div", _hoisted_1$6, [
    createElementVNode("table", _hoisted_2$4, [
      createElementVNode("tbody", null, [
        renderSlot(_ctx.$slots, "default")
      ])
    ])
  ]))
}

script$8.render = render;
script$8.__file = "src/blocks/table.vue";

const _hoisted_1$5 = { class: "notion-simple-table-row" };
const _hoisted_2$3 = { class: "notion-simple-table-cell-text" };
const __default__$6 = {
    name: "NotionTableRow",
};
var script$7 = /*#__PURE__*/ defineComponent({
    ...__default__$6,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { parent, properties, pass } = useNotionBlock(props);
        const { table_block_column_header: hasHeaderColumn, table_block_row_header: hasHeaderRow, table_block_column_order: columns, } = parent.value.value.format;
        const cell = (columnId) => {
            return properties.value[columnId];
        };
        const isHeader = (columnIndex) => {
            return (hasHeaderColumn && props.contentIndex == 0) || (hasHeaderRow && columnIndex == 0);
        };
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("tr", _hoisted_1$5, [
                (openBlock(true), createElementBlock(Fragment, null, renderList(unref(columns), (columnId, columnIndex) => {
                    return (openBlock(), createElementBlock("td", {
                        key: columnIndex,
                        class: "notion-simple-table-data"
                    }, [
                        createElementVNode("div", {
                            class: normalizeClass({ 'notion-simple-table-header': isHeader(columnIndex) })
                        }, [
                            createElementVNode("div", _hoisted_2$3, [
                                createVNode(script$o, mergeProps({
                                    text: cell(columnId)
                                }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                            ])
                        ], 2 /* CLASS */)
                    ]));
                }), 128 /* KEYED_FRAGMENT */))
            ]));
        };
    }
});

script$7.__file = "src/blocks/table-row.vue";

const _hoisted_1$4 = {
    key: 1,
    class: "notion-blank"
};
const __default__$5 = {
    name: "NotionText",
};
var script$6 = /*#__PURE__*/ defineComponent({
    ...__default__$5,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { properties, title, pass, blockColorClass } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (unref(properties))
                ? (openBlock(), createElementBlock("p", {
                    key: 0,
                    class: normalizeClass(['notion-text', unref(blockColorClass)()])
                }, [
                    createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ], 2 /* CLASS */))
                : (openBlock(), createElementBlock("div", _hoisted_1$4, " "));
        };
    }
});

script$6.__file = "src/blocks/text.vue";

const _hoisted_1$3 = { class: "notion-to-do-item" };
const _hoisted_2$2 = ["value", "checked"];
const __default__$4 = {
    name: "NotionTodo",
};
var script$5 = /*#__PURE__*/ defineComponent({
    ...__default__$4,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { title, properties, pass } = useNotionBlock(props);
        const checked = computed(() => properties.value?.checked?.[0] == "Yes");
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("label", _hoisted_1$3, [
                createElementVNode("input", {
                    type: "checkbox",
                    class: "notion-property-checkbox",
                    value: unref(checked),
                    checked: unref(checked),
                    disabled: "true"
                }, null, 8 /* PROPS */, _hoisted_2$2),
                createElementVNode("label", {
                    class: normalizeClass({ 'notion-to-do-checked': unref(checked) })
                }, [
                    createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ], 2 /* CLASS */)
            ]));
        };
    }
});

script$5.__file = "src/blocks/todo.vue";

const _hoisted_1$2 = { class: "notion-toggle" };
const __default__$3 = {
    name: "NotionToggle",
};
var script$4 = /*#__PURE__*/ defineComponent({
    ...__default__$3,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { title, pass } = useNotionBlock(props);
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("details", _hoisted_1$2, [
                createElementVNode("summary", null, [
                    createVNode(script$o, mergeProps({ text: unref(title) }, unref(pass)), null, 16 /* FULL_PROPS */, ["text"])
                ]),
                createElementVNode("div", null, [
                    renderSlot(_ctx.$slots, "default")
                ])
            ]));
        };
    }
});

script$4.__file = "src/blocks/toggle.vue";

const __default__$2 = {
    name: "NotionTableOfContentItem",
};
var script$3 = /*#__PURE__*/ defineComponent({
    ...__default__$2,
    props: { text: Object, level: { type: Number, default: 0 } },
    setup(__props) {
        const props = __props;
        const computedText = computed(() => (props.text ? props.text.map((i) => i[0]).join("") : ""));
        const computedStyle = computed(() => ({
            paddingLeft: 1.5 * props.level + "rem",
        }));
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("span", {
                class: "notion-table-of-contents-item",
                style: normalizeStyle(unref(computedStyle))
            }, toDisplayString(unref(computedText)), 5 /* TEXT, STYLE */));
        };
    }
});

script$3.__file = "src/blocks/helpers/table-of-contents-item.vue";

const _hoisted_1$1 = { class: "notion-table-of-contents" };
const _hoisted_2$1 = ["target", "href"];
const __default__$1 = {
    name: "NotionTableOfContent",
};
var script$2 = /*#__PURE__*/ defineComponent({
    ...__default__$1,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { block, parent, hasPageLinkOptions, pageLinkProps } = useNotionBlock(props);
        const headers = ["header", "sub_header", "sub_sub_header"];
        const headerObjects = computed(() => {
            if (!props.blockMap)
                return;
            let temp = [];
            Object.entries(props.blockMap).forEach(([key, value]) => {
                if (headers.includes(value.value.type) && value.value.parent_id == parent.value.value.id) {
                    let level = 0;
                    if (temp.length) {
                        let prevBlock = temp[temp.length - 1];
                        if (value.value.type == "header") ;
                        else if (value.value.type == "sub_header") {
                            level = 1;
                        }
                        else if (value.value.type == prevBlock.value.type) {
                            level = prevBlock.level;
                        }
                        else if (value.value.type != prevBlock.value.type) {
                            level = prevBlock.level + 1;
                        }
                    }
                    temp.push({ ...value, level });
                }
            });
            return temp;
        });
        console.log(headerObjects);
        return (_ctx, _cache) => {
            return (openBlock(), createElementBlock("div", _hoisted_1$1, [
                (openBlock(true), createElementBlock(Fragment, null, renderList(unref(headerObjects), (header) => {
                    return (openBlock(), createElementBlock("a", {
                        class: "notion-page-link",
                        target: props.pageLinkTarget,
                        href: `#${header.value.id}`
                    }, [
                        createVNode(script$3, {
                            text: header.value.properties.title,
                            level: header.level
                        }, null, 8 /* PROPS */, ["text", "level"])
                    ], 8 /* PROPS */, _hoisted_2$1));
                }), 256 /* UNKEYED_FRAGMENT */))
            ]));
        };
    }
});

script$2.__file = "src/blocks/table-of-contents.vue";

const _hoisted_1 = {
    key: 0,
    style: { "width": "100%" }
};
const _hoisted_2 = {
    key: 10,
    class: "notion-row"
};
const _hoisted_3 = {
    key: 17,
    class: "notion-hr"
};
var script$1 = /*#__PURE__*/ defineComponent({
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { pass, type, format, isType } = useNotionBlock(props);
        if (!availableType.includes(type.value))
            console.warn(`${type.value.toUpperCase()} is not implemented yet`);
        // console.log(type.value)
        return (_ctx, _cache) => {
            return (unref(isType)('page'))
                ? (openBlock(), createElementBlock("div", _hoisted_1, [
                    createVNode(script$a, normalizeProps(guardReactiveProps(unref(pass))), {
                        default: withCtx(() => [
                            renderSlot(_ctx.$slots, "default")
                        ]),
                        _: 3 /* FORWARDED */
                    }, 16 /* FULL_PROPS */)
                ]))
                : (unref(isType)(['header', 'sub_header', 'sub_sub_header']))
                    ? (openBlock(), createBlock(script$d, normalizeProps(mergeProps({ key: 1 }, unref(pass))), null, 16 /* FULL_PROPS */))
                    : (unref(isType)('bookmark'))
                        ? (openBlock(), createBlock(script$n, normalizeProps(mergeProps({ key: 2 }, unref(pass))), null, 16 /* FULL_PROPS */))
                        : (unref(isType)('callout'))
                            ? (openBlock(), createBlock(script$l, normalizeProps(mergeProps({ key: 3 }, unref(pass))), null, 16 /* FULL_PROPS */))
                            : (unref(isType)('code'))
                                ? (openBlock(), createBlock(script$j, normalizeProps(mergeProps({ key: 4 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                : (unref(isType)('equation'))
                                    ? (openBlock(), createBlock(script$h, normalizeProps(mergeProps({ key: 5 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                    : (unref(isType)('text'))
                                        ? (openBlock(), createBlock(script$6, normalizeProps(mergeProps({ key: 6 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                        : (unref(isType)('quote'))
                                            ? (openBlock(), createBlock(script$9, normalizeProps(mergeProps({ key: 7 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                            : (unref(isType)('to_do'))
                                                ? (openBlock(), createBlock(script$5, normalizeProps(mergeProps({ key: 8 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                                : (unref(isType)('toggle'))
                                                    ? (openBlock(), createBlock(script$4, normalizeProps(mergeProps({ key: 9 }, unref(pass))), {
                                                        default: withCtx(() => [
                                                            renderSlot(_ctx.$slots, "default")
                                                        ]),
                                                        _: 3 /* FORWARDED */
                                                    }, 16 /* FULL_PROPS */))
                                                    : (unref(isType)('column_list'))
                                                        ? (openBlock(), createElementBlock("div", _hoisted_2, [
                                                            renderSlot(_ctx.$slots, "default")
                                                        ]))
                                                        : (unref(isType)('column'))
                                                            ? (openBlock(), createBlock(script$i, {
                                                                key: 11,
                                                                format: unref(format)
                                                            }, {
                                                                default: withCtx(() => [
                                                                    renderSlot(_ctx.$slots, "default")
                                                                ]),
                                                                _: 3 /* FORWARDED */
                                                            }, 8 /* PROPS */, ["format"]))
                                                            : (unref(isType)(['bulleted_list', 'numbered_list']))
                                                                ? (openBlock(), createBlock(script$b, normalizeProps(mergeProps({ key: 12 }, unref(pass))), {
                                                                    default: withCtx(() => [
                                                                        renderSlot(_ctx.$slots, "default")
                                                                    ]),
                                                                    _: 3 /* FORWARDED */
                                                                }, 16 /* FULL_PROPS */))
                                                                : (unref(isType)(['image', 'embed', 'figma', 'video', 'audio']))
                                                                    ? (openBlock(), createBlock(script$e, normalizeProps(mergeProps({ key: 13 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                                                    : (unref(isType)('table'))
                                                                        ? (openBlock(), createBlock(script$8, normalizeProps(mergeProps({ key: 14 }, unref(pass))), {
                                                                            default: withCtx(() => [
                                                                                renderSlot(_ctx.$slots, "default")
                                                                            ]),
                                                                            _: 3 /* FORWARDED */
                                                                        }, 16 /* FULL_PROPS */))
                                                                        : (unref(isType)('table_row'))
                                                                            ? (openBlock(), createBlock(script$7, normalizeProps(mergeProps({ key: 15 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                                                            : (unref(isType)('table_of_contents'))
                                                                                ? (openBlock(), createBlock(script$2, normalizeProps(mergeProps({ key: 16 }, unref(pass))), null, 16 /* FULL_PROPS */))
                                                                                : (unref(isType)('divider'))
                                                                                    ? (openBlock(), createElementBlock("hr", _hoisted_3))
                                                                                    : createCommentVNode("v-if", true);
        };
    }
});

script$1.__file = "src/components/block.vue";

const __default__ = {
    name: "NotionRenderer",
};
var script = /*#__PURE__*/ defineComponent({
    ...__default__,
    props: { ...defineNotionProps },
    setup(__props) {
        const props = __props;
        //@ts-ignore
        const { pass, block } = useNotionBlock(props);
        return (_ctx, _cache) => {
            const _component_NotionRenderer = resolveComponent("NotionRenderer", true);
            return (unref(block))
                ? (openBlock(), createBlock(script$1, normalizeProps(mergeProps({ key: 0 }, unref(pass))), {
                    default: withCtx(() => [
                        (openBlock(true), createElementBlock(Fragment, null, renderList(unref(block).value.content, (contentId, contentIndex) => {
                            return (openBlock(), createBlock(_component_NotionRenderer, mergeProps(unref(pass), {
                                key: contentId,
                                level: unref(pass).level + 1,
                                "content-id": contentId,
                                "content-index": contentIndex
                            }), null, 16 /* FULL_PROPS */, ["level", "content-id", "content-index"]));
                        }), 128 /* KEYED_FRAGMENT */))
                    ]),
                    _: 1 /* STABLE */
                }, 16 /* FULL_PROPS */))
                : createCommentVNode("v-if", true);
        };
    }
});

script.__file = "src/components/notion-renderer.vue";

var components = /*#__PURE__*/Object.freeze({
  __proto__: null,
  NotionRenderer: script
});

const getPageTable = async (pageId, apiUrl = "https://api.vue-notion.workers.dev/v1") => await fetch(`${apiUrl}/table/${pageId}`)
    .then((res) => res.json())
    .then((data) => data)
    .catch((err) => err);
const getPageBlocks = async (pageId, apiUrl = "https://api.vue-notion.workers.dev/v1") => await fetch(`${apiUrl}/page/${pageId}`)
    .then((res) => res.json())
    .then((data) => data)
    .catch((err) => err);

var Role;
(function (Role) {
    Role["Reader"] = "reader";
})(Role || (Role = {}));

const useGetPageBlocks = (...arg) => {
    const data = ref();
    onMounted(async () => {
        data.value = await getPageBlocks(...arg);
    });
    return {
        data,
    };
};
const useGetPageTable = (...arg) => {
    const data = ref();
    onMounted(async () => {
        data.value = await getPageTable(...arg);
    });
    return {
        data,
    };
};

// Default export is library as a whole, registered via Vue.use()
var index = {
    install: (app) => {
        Object.entries(components).forEach(([componentName, component]) => {
            app.component(componentName, component);
        });
    },
};

export { script as NotionRenderer, Role, index as default, getPageBlocks, getPageTable, useGetPageBlocks, useGetPageTable };
